<!--
SPDX-FileCopyrightText: Contributors to the Power Grid Model project <powergridmodel@lfenergy.org>

SPDX-License-Identifier: MPL-2.0
-->

# Component Test Case: Node (Basic)

Test case for validation of basic functioning the node component for symmetrical power flow calculations in pandapower.

- A node can have 2 states: energized and non-energized.

The circuit diagram is as follows:

```txt
source_4--node_1       node_2
```
